import Collection
import TempEntityClass
import Text
from django.conf import settings
from django.contrib.auth.decorators import login_required
from django.contrib.contenttypes.models import ContentType
from django.shortcuts import render
from django.utils.decorators import method_decorator
from django.views.generic import View
from django.conf import settings
from apis_core.apis_metainfo.models import Collection, Text, TempEntityClass
from apis_highlighter.forms import SelectAnnotatorAgreementCollection

if "annotator agreement" in getattr(settings, "APIS_COMPONENTS", []):
    from apis_core.helper_functions.inter_annotator_agreement import (
        InternalDataAgreement,
    )


@method_decorator(login_required, name="dispatch")
class ComputeAgreement(View):
    def get(self, request):
        form = SelectAnnotatorAgreementCollection()
        return render(
            request, "apis_highlighter/calculate_agreement.html", {"form": form}
        )

    def post(self, request, *args, **kwargs):
        form = SelectAnnotatorAgreementCollection(request.POST)
        if form.is_valid():
            gold_standard = form.cleaned_data.get("gold_standard")
            user_group = form.cleaned_data.get("user_group")
            metrics = form.cleaned_data.get("metrics")
            format_string = form.cleaned_data.get("format_string")
            ann_proj_pk = form.cleaned_data.get("anno_proj")
            collection = form.cleaned_data.get("collection")
            kind_instance = form.cleaned_data.get("kind_instance")
            text_type = form.cleaned_data.get("text_type")
            met_dict = dict(form.fields["metrics"].choices)
            title1 = met_dict[form.cleaned_data["metrics"]]
            txt = Text.objects.all()
            ent = False
            if kind_instance:
                col = Collection.objects.get(pk=collection)
                ent = ContentType.objects.get_for_id(kind_instance).model_class()
                ent = ent.objects.filter(collection=col)
            elif collection:
                col = Collection.objects.get(pk=collection)
                ent = TempEntityClass.objects.filter(collection=col)
            if ent:
                txt = txt.filter(tempentityclass__in=ent).distinct()
            if text_type:
                txt = txt.filter(kind_id__in=text_type)
            tab1, tab2 = InternalDataAgreement(
                txt,
                ann_proj_pk,
                user_group,
                gold_standard=gold_standard,
                metrics=metrics,
                combine=True,
                format_string=format_string,
            ).get_html_table()
            return render(
                request,
                "apis_highlighter/calculate_agreement.html",
                {"form": form, "tab1": tab1, "tab2": tab2, "title1": title1},
            )



# Generated by Django 2.2.11 on 2021-06-25 09:31

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('apis_highlighter', '0004_auto_20210623_2124'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='annotation',
            name='entity_link',
        ),
    ]



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['apis_highlighter', 'apis_highlighter.migrations']

package_data = \
{'': ['*'],
 'apis_highlighter': ['static/apis_highlighter/*',
                      'templates/apis_highlighter/*']}

install_requires = \
['apis-core>=0.16.14,<0.17.0']

setup_kwargs = {
    'name': 'apis-highlighter',
    'version': '0.8.13',
    'description': 'Highlighter module for annotations in APIS framework',
    'long_description': None,
    'author': 'Matthias Schlögl',
    'author_email': 'm.schloegl@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<3.7',
}


setup(**setup_kwargs)



# Generated by Django 2.1.12 on 2020-01-21 12:27

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='ActiveLearningProject',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('sampling_strategy', models.CharField(max_length=4)),
                ('rebuild', models.IntegerField()),
                ('log_dir', models.CharField(max_length=255)),
            ],
            options={
                'db_table': 'highlighter_activelearningproject',
            },
        ),
        migrations.CreateModel(
            name='Annotation',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('start', models.PositiveIntegerField()),
                ('end', models.PositiveIntegerField()),
                ('orig_string', models.CharField(blank=True, max_length=255, null=True)),
                ('status', models.CharField(blank=True, choices=[('del', 'deleted'), ('ap', 'approved')], max_length=4, null=True)),
            ],
            options={
                'db_table': 'highlighter_annotation',
            },
        ),
        migrations.CreateModel(
            name='AnnotationProject',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('description', models.TextField(blank=True, null=True)),
            ],
            options={
                'db_table': 'highlighter_annotationproject',
            },
        ),
        migrations.CreateModel(
            name='MenuEntry',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('kind', models.CharField(choices=[('txt', 'Text field'), ('frm', 'Form'), ('m', 'menu entry'), ('fn', 'Javascript function')], default='txt', max_length=4)),
                ('name', models.CharField(blank=True, max_length=255, null=True)),
            ],
            options={
                'db_table': 'highlighter_menuentry',
            },
        ),
        migrations.CreateModel(
            name='Project',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('description', models.TextField(blank=True, null=True)),
                ('base_url', models.URLField(blank=True, null=True)),
                ('store_text', models.BooleanField(default=False)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'db_table': 'highlighter_project',
            },
        ),
        migrations.CreateModel(
            name='TextHigh',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(blank=True, max_length=255, null=True)),
                ('text_type', models.CharField(choices=[('ft', 'Full Text'), ('id', 'Text ID'), ('cl', 'Text Class')], default='cl', max_length=3)),
                ('uri', models.URLField(blank=True, null=True)),
                ('text', models.TextField(blank=True, null=True)),
                ('text_id', models.PositiveIntegerField(blank=True, null=True)),
                ('text_class', models.CharField(blank=True, max_length=255, null=True)),
                ('project', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='apis_highlighter.Project')),
            ],
            options={
                'db_table': 'highlighter_texthigh',
            },
        ),
        migrations.CreateModel(
            name='VocabularyAPI',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(blank=True, max_length=255, null=True)),
                ('api_endpoint', models.CharField(blank=True, max_length=255, null=True)),
                ('method', models.CharField(choices=[('l', 'local'), ('o', 'open skos')], default='l', max_length=2)),
            ],
            options={
                'db_table': 'highlighter_vocabularyapi',
            },
        ),
        migrations.AddField(
            model_name='menuentry',
            name='api',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='apis_highlighter.VocabularyAPI'),
        ),
        migrations.AddField(
            model_name='menuentry',
            name='parent',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='parent_menuEntry', to='apis_highlighter.MenuEntry'),
        ),
        migrations.AddField(
            model_name='menuentry',
            name='project',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='apis_highlighter.Project'),
        ),
        migrations.AddField(
            model_name='annotation',
            name='annotation_project',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='apis_highlighter.AnnotationProject'),
        ),
    ]
